@@ -13,13 +13,14 @@ Puppet::Type.newtype(:glance_image) do
       source           => 'http://uec-images.ubuntu.com/releases/precise/release/ubuntu-12.04-server-cloudimg-amd64-disk1.img'
       min_ram          => 1234,
       min_disk         => 1234,
+      properties       => { 'img_key' => img_value }
     }
 
     Known problems / limitations:
-      * All images are managed by the glance service. 
+      * All images are managed by the glance service.
         This means that since users are unable to manage their own images via this type,
         is_public is really of no use. You can probably hide images this way but that's all.
-      * As glance image names do not have to be unique, you must ensure that your glance 
+      * As glance image names do not have to be unique, you must ensure that your glance
         repository does not have any duplicate names prior to using this.
       * Ensure this is run on the same server as the glance-api service.
 
@@ -34,9 +35,7 @@ Puppet::Type.newtype(:glance_image) do
 
   newproperty(:id) do
     desc 'The unique id of the image'
-    validate do |v|
-      raise(Puppet::Error, 'This is a read only property')
-    end
+    newvalues(/[0-9a-f]{8}-([0-9a-f]{4}-){3}[0-9a-f]{12}/)
   end
 
   newparam(:location) do
@@ -66,7 +65,7 @@ Puppet::Type.newtype(:glance_image) do
 
   newproperty(:disk_format) do
     desc "The format of the disk"
-    newvalues(:ami, :ari, :aki, :vhd, :vmd, :raw, :qcow2, :vdi, :iso)
+    newvalues(:ami, :ari, :aki, :vhd, :vmdk, :raw, :qcow2, :vdi, :iso)
   end
 
   newparam(:source) do
@@ -74,21 +73,39 @@ Puppet::Type.newtype(:glance_image) do
     newvalues(/\S+/)
   end
 
-  newparam(:min_ram) do
+  newproperty(:min_ram) do
     desc "The minimal ram size"
     newvalues(/\d+/)
   end
 
-  newparam(:min_disk) do
+  newproperty(:min_disk) do
     desc "The minimal disk size"
     newvalues(/\d+/)
   end
 
+  newproperty(:properties) do
+    desc "The set of image properties"
+
+    munge do |value|
+      return value if value.is_a? Hash
+
+      # wrap property value in commas
+      value.gsub!(/=(\w+)/, '=\'\1\'')
+      Hash[value.scan(/(\S+)='([^']*)'/)]
+    end
+
+    validate do |value|
+      return true if value.is_a? Hash
+
+      value.split(',').each do |property|
+        raise ArgumentError, "Key/value pairs should be separated by an =" unless property.include?('=')
+      end
+    end
+  end
+
   # Require the Glance service to be running
   autorequire(:service) do
-    ['glance']
+    ['glance-api', 'glance-registry']
   end
 
 end
-
-
